-- ============================================================================
-- Project:	ddbench - Logic Programming and Database Benchmarks
-- Filename:	db/input_files.sql
-- Purpose:	Database for Benchmark Runs: Data of Iput Files for Benchmarks
-- Last Change:	04.02.2018
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2019 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- Table for Data Files (Input Files to Benchmarks):
-- ============================================================================

-- CREATE TABLE INPUT_FILE(
--	FILE_ID     VARCHAR(10)  NOT NULL,
--	SEQ_NO      NUMERIC(3)   NOT NULL,
--	ITYPE       VARCHAR(8)   NOT NULL,
--	LINES       NUMERIC(12)  NOT NULL, -- should be the number of facts
--	BYTES       NUMERIC(12)  NOT NULL, -- refers to Datalog facts version
--	FILENAME    VARCHAR(40)  NOT NULL, -- without extension
--	CONSTRAINT INPUT_FILE_PK
--		PRIMARY KEY (FILE_ID),
--	CONSTRAINT INPUT_FILE_KEY2
--		UNIQUE (SEQ_NO),
--	CONSTRAINT INPUT_FILE_SEQ_NO_NOT_NEGATIVE
--		CHECK(SEQ_NO >= 0),
--	CONSTRAINT INPUT_FILE_REF_INPUT_TYPE
--		FOREIGN KEY (ITYPE) REFERENCES INPUT_TYPE,
--	CONSTRAINT INPUT_FILE_LINES_NOT_NEGATIVE
--		CHECK(LINES >= 0),
--	CONSTRAINT INPUT_FILE_BYTES_NOT_NEGATIVE
--		CHECK(BYTES >= 0));

-- wc was used to compute lines and bytes

INSERT INTO INPUT_FILE VALUES
  ('k465',     101, 'tc',   216225,    3141075, 'tc_complete_465');
INSERT INTO INPUT_FILE VALUES
  ('k500',     102, 'tc',   250000,    3640000, 'tc_complete_500');
INSERT INTO INPUT_FILE VALUES
  ('k585',     103, 'tc',   342225,    5004675, 'tc_complete_585');
INSERT INTO INPUT_FILE VALUES
  ('k670',     104, 'tc',   448900,    6586100, 'tc_complete_670');
INSERT INTO INPUT_FILE VALUES
  ('k735',     105, 'tc',   540225,    7941675, 'tc_complete_735');
INSERT INTO INPUT_FILE VALUES
  ('k795',     106, 'tc',   632025,    9305475, 'tc_complete_795');
INSERT INTO INPUT_FILE VALUES
  ('k845',     107, 'tc',   714025,   10524475, 'tc_complete_845');
INSERT INTO INPUT_FILE VALUES
  ('k890',     108, 'tc',   792100,   11685700, 'tc_complete_890');
INSERT INTO INPUT_FILE VALUES
  ('k930',     109, 'tc',   864900,   12768900, 'tc_complete_930');
INSERT INTO INPUT_FILE VALUES
  ('k965',     110, 'tc',   931225,   13756075, 'tc_complete_965');
INSERT INTO INPUT_FILE VALUES
  ('k1k',      111, 'tc',  1000000,   14780000, 'tc_complete_1000');
INSERT INTO INPUT_FILE VALUES
  ('k1k5',      112, 'tc',  0,   0, 'tc_complete_1500'); -- TODO Fix Size
INSERT INTO INPUT_FILE VALUES
  ('k2k',      113, 'tc',  4000000,   63560000, 'tc_complete_2000');
INSERT INTO INPUT_FILE VALUES
  ('t500',     121, 'tc',   124750,    1816360, 'tc_total_500');
INSERT INTO INPUT_FILE VALUES
  ('t585',     122, 'tc',   170820,    2498060, 'tc_total_585');
INSERT INTO INPUT_FILE VALUES
  ('t735',     123, 'tc',   269745,    3965435, 'tc_total_735');
INSERT INTO INPUT_FILE VALUES
  ('t845',     124, 'tc',   356590,    5256010, 'tc_total_845');
INSERT INTO INPUT_FILE VALUES
  ('t930',     125, 'tc',   431985,    6377585, 'tc_total_930');
INSERT INTO INPUT_FILE VALUES
  ('t1k',      126, 'tc',   499500,    7382610, 'tc_total_1000');
INSERT INTO INPUT_FILE VALUES
  ('t1065',    127, 'tc',   566580,    8450820, 'tc_total_1065');
INSERT INTO INPUT_FILE VALUES
  ('t1120',    128, 'tc',   626640,    9410790, 'tc_total_1120');
INSERT INTO INPUT_FILE VALUES
  ('t1170',    129, 'tc',   683865,   10328115, 'tc_total_1170');
INSERT INTO INPUT_FILE VALUES
  ('t1215',    130, 'tc',   737505,   11190045, 'tc_total_1215');
INSERT INTO INPUT_FILE VALUES
  ('t1260',    131, 'tc',   793170,   12086400, 'tc_total_1260');
INSERT INTO INPUT_FILE VALUES
  ('t1k5',      132, 'tc',   0,    0, 'tc_total_1500'); -- TODO Fix Size
INSERT INTO INPUT_FILE VALUES
  ('t2k',      133, 'tc',  1999000,   31764110, 'tc_total_2000');
INSERT INTO INPUT_FILE VALUES
  ('c1k',      141, 'tc',     1000,      14780, 'tc_cycle_1000');
INSERT INTO INPUT_FILE VALUES
  ('c2k',      142, 'tc',     2000,      31780, 'tc_cycle_2000');
INSERT INTO INPUT_FILE VALUES
  ('c3k',      143, 'tc',     3000,      48780, 'tc_cycle_3000');
INSERT INTO INPUT_FILE VALUES
  ('c4k',      144, 'tc',     4000,      65780, 'tc_cycle_4000');
INSERT INTO INPUT_FILE VALUES
  ('c10k',     145, 'tc',    10000,     167780, 'tc_cycle_10000');
INSERT INTO INPUT_FILE VALUES
  ('c14k1',    146, 'tc',    14100,     245680, 'tc_cycle_14100');
INSERT INTO INPUT_FILE VALUES
  ('c17k3',    147, 'tc',    17300,     306480, 'tc_cycle_17300');
INSERT INTO INPUT_FILE VALUES
  ('c20k',     148, 'tc',    20000,     357780, 'tc_cycle_20000');
INSERT INTO INPUT_FILE VALUES
  ('c22k4',    149, 'tc',    22400,     403380, 'tc_cycle_22400');
INSERT INTO INPUT_FILE VALUES
  ('c24k5',    150, 'tc',    24500,     443280, 'tc_cycle_24500');
INSERT INTO INPUT_FILE VALUES
  ('c26k5',    151, 'tc',    26500,     481280, 'tc_cycle_26500');
INSERT INTO INPUT_FILE VALUES
  ('c28k3',    152, 'tc',    28300,     515480, 'tc_cycle_28300');
INSERT INTO INPUT_FILE VALUES
  ('c30k',     153, 'tc',    30000,     547780, 'tc_cycle_30000');
INSERT INTO INPUT_FILE VALUES
  ('c31k6',    154, 'tc',    31600,     578180, 'tc_cycle_31600');
INSERT INTO INPUT_FILE VALUES
  ('s1k_1',    161, 'tc',     2000,      29560, 'tc_shorted_cycle_1000_1');
INSERT INTO INPUT_FILE VALUES
  ('s1k_2',    162, 'tc',     3000,      44340, 'tc_shorted_cycle_1000_2');
INSERT INTO INPUT_FILE VALUES
  ('s1k_3',    163, 'tc',     4000,      59120, 'tc_shorted_cycle_1000_3');
INSERT INTO INPUT_FILE VALUES
  ('s1k_4',    164, 'tc',     5000,      73900, 'tc_shorted_cycle_1000_4');
INSERT INTO INPUT_FILE VALUES
  ('s1k_5',    165, 'tc',     6000,      88680, 'tc_shorted_cycle_1000_5');
INSERT INTO INPUT_FILE VALUES
  ('s1k2_1',   166, 'tc',     2400,      36360, 'tc_shorted_cycle_1200_1');
INSERT INTO INPUT_FILE VALUES
  ('s1k2_2',   167, 'tc',     3600,      54540, 'tc_shorted_cycle_1200_2');
INSERT INTO INPUT_FILE VALUES
  ('s1k2_4',   168, 'tc',     6000,      90900, 'tc_shorted_cycle_1200_4');
INSERT INTO INPUT_FILE VALUES
  ('s1k2_5',   169, 'tc',     3357,      50265, 'tc_shorted_cycle_1200_5');
INSERT INTO INPUT_FILE VALUES
  ('s2k_1',    170, 'tc',     4000,      63560, 'tc_shorted_cycle_2000_1');
INSERT INTO INPUT_FILE VALUES
  ('s2k_2',    171, 'tc',     6000,      95340, 'tc_shorted_cycle_2000_2');
INSERT INTO INPUT_FILE VALUES
  ('s2k_3',    172, 'tc',     8000,     127120, 'tc_shorted_cycle_2000_3');
INSERT INTO INPUT_FILE VALUES
  ('s2k_4',    173, 'tc',    10000,     158900, 'tc_shorted_cycle_2000_4');
INSERT INTO INPUT_FILE VALUES
  ('s2k_5',    174, 'tc',    12000,     190680, 'tc_shorted_cycle_2000_5');
INSERT INTO INPUT_FILE VALUES
  ('s2k4_1',   175, 'tc',     4800,      77160, 'tc_shorted_cycle_2400_1');
INSERT INTO INPUT_FILE VALUES
  ('s2k4_2',   176, 'tc',     7200,     115740, 'tc_shorted_cycle_2400_2');
INSERT INTO INPUT_FILE VALUES
  ('s2k4_4',   177, 'tc',    12000,     192900, 'tc_shorted_cycle_2400_4');
INSERT INTO INPUT_FILE VALUES
  ('s2k4_5',   178, 'tc',    14400,     231480, 'tc_shorted_cycle_2400_5');
INSERT INTO INPUT_FILE VALUES
  ('s4k8_1',   179, 'tc',     9600,     158760, 'tc_shorted_cycle_4800_1');
INSERT INTO INPUT_FILE VALUES
  ('s4k8_2',   180, 'tc',    14400,     238140, 'tc_shorted_cycle_4800_2');
INSERT INTO INPUT_FILE VALUES
  ('s4k8_4',   181, 'tc',    24000,     396900, 'tc_shorted_cycle_4800_4');
INSERT INTO INPUT_FILE VALUES
  ('s4k8_5',   182, 'tc',    28800,     476280, 'tc_shorted_cycle_4800_5');
INSERT INTO INPUT_FILE VALUES
  ('s6k3_1',   183, 'tc',    12600,     209760, 'tc_shorted_cycle_6300_1');
INSERT INTO INPUT_FILE VALUES
  ('s6k3_2',   184, 'tc',    18900,     314640, 'tc_shorted_cycle_6300_2');
INSERT INTO INPUT_FILE VALUES
  ('s6k3_4',   185, 'tc',    31500,     524400, 'tc_shorted_cycle_6300_4');
INSERT INTO INPUT_FILE VALUES
  ('s6k3_5',   186, 'tc',    37800,     629280, 'tc_shorted_cycle_6300_5');
INSERT INTO INPUT_FILE VALUES
  ('s7k2_1',   187, 'tc',    14400,     240360, 'tc_shorted_cycle_7200_1');
INSERT INTO INPUT_FILE VALUES
  ('s7k2_2',   188, 'tc',    21600,     360540, 'tc_shorted_cycle_7200_2');
INSERT INTO INPUT_FILE VALUES
  ('s7k2_4',   189, 'tc',    36000,     600900, 'tc_shorted_cycle_7200_4');
INSERT INTO INPUT_FILE VALUES
  ('s7k2_5',   190, 'tc',    43200,     721080, 'tc_shorted_cycle_7200_5');
INSERT INTO INPUT_FILE VALUES
  ('s9k_1',    191, 'tc',    18000,     301560, 'tc_shorted_cycle_9000_1');
INSERT INTO INPUT_FILE VALUES
  ('s9k_2',    192, 'tc',    27000,     452340, 'tc_shorted_cycle_9000_2');
INSERT INTO INPUT_FILE VALUES
  ('s9k_4',    193, 'tc',    45000,     753900, 'tc_shorted_cycle_9000_4');
INSERT INTO INPUT_FILE VALUES
  ('s9k_5',    194, 'tc',    54000,     904680, 'tc_shorted_cycle_9000_5');
INSERT INTO INPUT_FILE VALUES
  ('s12k_1',   195, 'tc',    24000,     411560, 'tc_shorted_cycle_12000_1');
INSERT INTO INPUT_FILE VALUES
  ('s12k_2',   196, 'tc',    36000,     617340, 'tc_shorted_cycle_12000_2');
INSERT INTO INPUT_FILE VALUES
  ('s12k_4',   197, 'tc',    60000,    1028900, 'tc_shorted_cycle_12000_4');
INSERT INTO INPUT_FILE VALUES
  ('s12k_5',   198, 'tc',    72000,    1234680, 'tc_shorted_cycle_12000_5');
INSERT INTO INPUT_FILE VALUES
  ('s13k5_1',  199, 'tc',    27000,     468560, 'tc_shorted_cycle_13500_1');
INSERT INTO INPUT_FILE VALUES
  ('s13k5_2',  200, 'tc',    40500,     702840, 'tc_shorted_cycle_13500_2');
INSERT INTO INPUT_FILE VALUES
  ('s13k5_4',  201, 'tc',    67500,    1171400, 'tc_shorted_cycle_13500_4');
INSERT INTO INPUT_FILE VALUES
  ('s13k5_5',  202, 'tc',    81000,    1405680, 'tc_shorted_cycle_13500_5');
INSERT INTO INPUT_FILE VALUES
  ('s15k9_1',  203, 'tc',    31800,     559760, 'tc_shorted_cycle_15900_1');
INSERT INTO INPUT_FILE VALUES
  ('s15k9_2',  204, 'tc',    47700,     839640, 'tc_shorted_cycle_15900_2');
INSERT INTO INPUT_FILE VALUES
  ('s15k9_4',  205, 'tc',    79500,    1399400, 'tc_shorted_cycle_15900_4');
INSERT INTO INPUT_FILE VALUES
  ('s15k9_5',  206, 'tc',    95400,    1679280, 'tc_shorted_cycle_15900_5');
INSERT INTO INPUT_FILE VALUES
  ('s18k6_1',  207, 'tc',    37200,     662360, 'tc_shorted_cycle_18600_1');
INSERT INTO INPUT_FILE VALUES
  ('s18k6_2',  208, 'tc',    55800,     993540, 'tc_shorted_cycle_18600_2');
INSERT INTO INPUT_FILE VALUES
  ('s18k6_4',  209, 'tc',    93000,    1655900, 'tc_shorted_cycle_18600_4');
INSERT INTO INPUT_FILE VALUES
  ('s18k6_5',  210, 'tc',   111600,    1987080, 'tc_shorted_cycle_18600_5');
INSERT INTO INPUT_FILE VALUES
  ('p1k',      221, 'tc',      999,      14767, 'tc_path_1000');
INSERT INTO INPUT_FILE VALUES
  ('p2k',      222, 'tc',     1999,      31766, 'tc_path_2000');
INSERT INTO INPUT_FILE VALUES
  ('p3k',      223, 'tc',     2999,      48766, 'tc_path_3000');
INSERT INTO INPUT_FILE VALUES
  ('p4k',      224, 'tc',     3999,      65766, 'tc_path_4000');
INSERT INTO INPUT_FILE VALUES
  ('p14k1',    225, 'tc',    14099,     245665, 'tc_path_14100');
INSERT INTO INPUT_FILE VALUES
  ('p20k',     226, 'tc',    19999,     357765, 'tc_path_20000');
INSERT INTO INPUT_FILE VALUES
  ('p24k5',    227, 'tc',    24499,     443265, 'tc_path_24500');
INSERT INTO INPUT_FILE VALUES
  ('p28k3',    228, 'tc',    28299,     515465, 'tc_path_28300');
INSERT INTO INPUT_FILE VALUES
  ('p31k6',    229, 'tc',    31599,     578165, 'tc_path_31600');
INSERT INTO INPUT_FILE VALUES
  ('p34k6',    230, 'tc',    34599,     635165, 'tc_path_34600');
INSERT INTO INPUT_FILE VALUES
  ('p37k4',    231, 'tc',    37399,     688365, 'tc_path_37400');
INSERT INTO INPUT_FILE VALUES
  ('p40k',     232, 'tc',    39999,     737765, 'tc_path_40000');
INSERT INTO INPUT_FILE VALUES
  ('p42k4',    233, 'tc',    42399,     783365, 'tc_path_42400');
INSERT INTO INPUT_FILE VALUES
  ('p44k7',    234, 'tc',    44699,     827065, 'tc_path_44700');
INSERT INTO INPUT_FILE VALUES
  ('m4_2ki',   241, 'tc',     6144,     103341, 'tc_multipath_4_2048');
INSERT INTO INPUT_FILE VALUES
  ('m16_512',  242, 'tc',     7680,     128966, 'tc_multipath_16_512');
INSERT INTO INPUT_FILE VALUES
  ('m64_128',  243, 'tc',     8064,     135110, 'tc_multipath_64_128');
INSERT INTO INPUT_FILE VALUES
  ('m256_32',  244, 'tc',     8160,     136579, 'tc_multipath_256_32');
INSERT INTO INPUT_FILE VALUES
  ('m1ki_8',   245, 'tc',     8184,     136938, 'tc_multipath_1024_8');
INSERT INTO INPUT_FILE VALUES
  ('m4ki_2',   246, 'tc',     8190,     137022, 'tc_multipath_4096_2');
INSERT INTO INPUT_FILE VALUES
  ('b17',      251, 'tc',   131070,    2488088, 'tc_bintree_17');
INSERT INTO INPUT_FILE VALUES
  ('b18',      252, 'tc',   262142,    5171672, 'tc_bintree_18');
INSERT INTO INPUT_FILE VALUES
  ('b19',      253, 'tc',   524286,   10676696, 'tc_bintree_19');
INSERT INTO INPUT_FILE VALUES
  ('b20',      254, 'tc',  1048574,   21735320, 'tc_bintree_20');
INSERT INTO INPUT_FILE VALUES
  ('b21',      255, 'tc',  2097150,   44901144, 'tc_bintree_21');
INSERT INTO INPUT_FILE VALUES
  ('b22',      256, 'tc',  4194302,   93135640, 'tc_bintree_22');
INSERT INTO INPUT_FILE VALUES
  ('b23',      257, 'tc',  8388606,  189604632, 'tc_bintree_23');
INSERT INTO INPUT_FILE VALUES
  ('b24',      258, 'tc', 16777214,  389319832, 'tc_bintree_24');
INSERT INTO INPUT_FILE VALUES
  ('b25',      259, 'tc', 33554430,  805527448, 'tc_bintree_25');
INSERT INTO INPUT_FILE VALUES
  ('b26',      260, 'tc', 67108862, 1644388248, 'tc_bintree_26');
INSERT INTO INPUT_FILE VALUES
  ('y500_4k',  271, 'tc',     4499,      74378, 'tc_y_500_4000');
INSERT INTO INPUT_FILE VALUES
  ('y500_8k',  272, 'tc',     8499,     142378, 'tc_y_500_8000');
INSERT INTO INPUT_FILE VALUES
  ('y1k_4k',   273, 'tc',     4999,      83876, 'tc_y_1000_4000');
INSERT INTO INPUT_FILE VALUES
  ('y1k_8k',   274, 'tc',     8999,     151876, 'tc_y_1000_8000');
INSERT INTO INPUT_FILE VALUES
  ('y1k_15k',  275, 'tc',    15999,     282877, 'tc_y_1000_15000');
INSERT INTO INPUT_FILE VALUES
  ('y1k_25k',  276, 'tc',    25999,     472877, 'tc_y_1000_25000');
INSERT INTO INPUT_FILE VALUES
  ('y1k_35k',  277, 'tc',    35999,     662877, 'tc_y_1000_35000');
INSERT INTO INPUT_FILE VALUES
  ('y5k_15k',  278, 'tc',    19999,     358877, 'tc_y_5000_15000');
INSERT INTO INPUT_FILE VALUES
  ('y5k_25k',  279, 'tc',    29999,     548877, 'tc_y_5000_25000');
INSERT INTO INPUT_FILE VALUES
  ('y5k_35k',  280, 'tc',    39999,     738877, 'tc_y_5000_35000');
INSERT INTO INPUT_FILE VALUES
  ('y10k_15k', 281, 'tc',    24999,     463875, 'tc_y_10000_15000');
INSERT INTO INPUT_FILE VALUES
  ('y10k_25k', 282, 'tc',    34999,     653875, 'tc_y_10000_25000');
INSERT INTO INPUT_FILE VALUES
  ('y10k_35k', 283, 'tc',    44999,     843875, 'tc_y_10000_35000');
INSERT INTO INPUT_FILE VALUES
  ('u1k_50k',  301, 'tc',    50000,     739011, 'tc_uniform_1000_50000');
INSERT INTO INPUT_FILE VALUES
  ('u1k_125k', 302, 'tc',   125000,    1847511, 'tc_uniform_1000_125000');
INSERT INTO INPUT_FILE VALUES
  ('u1k_250k', 303, 'tc',   250000,    3695016, 'tc_uniform_1000_250000');
INSERT INTO INPUT_FILE VALUES
  ('u2k_200k', 304, 'tc',   200000,    3178014, 'tc_uniform_2000_200000');
INSERT INTO INPUT_FILE VALUES
  ('u2k_250k', 305, 'tc',   250000,    3972534, 'tc_uniform_2000_250000');
INSERT INTO INPUT_FILE VALUES
  ('u2k_500k', 306, 'tc',   500000,    7944982, 'tc_uniform_2000_500000');
INSERT INTO INPUT_FILE VALUES
  ('u2k_1m',   307, 'tc',  1000000,   15890006, 'tc_uniform_2000_1000000');
INSERT INTO INPUT_FILE VALUES
  ('a1k_50k',  311, 'tc',    50000,     738966, 'tc_acyc_1000_50000');
INSERT INTO INPUT_FILE VALUES
  ('a1k_125k', 312, 'tc',   125000,    1847531, 'tc_acyc_1000_125000');
INSERT INTO INPUT_FILE VALUES
  ('a1k_250k', 313, 'tc',   250000,    3695001, 'tc_acyc_1000_250000');
INSERT INTO INPUT_FILE VALUES
  ('a2k_200k', 314, 'tc',   200000,    3177896, 'tc_acyc_2000_200000');
INSERT INTO INPUT_FILE VALUES
  ('a2k_500k', 315, 'tc',   500000,    7944738, 'tc_acyc_2000_500000');
INSERT INTO INPUT_FILE VALUES
  ('a2k_1m',   316, 'tc',  1000000,   15890152, 'tc_acyc_2000_1000000');

INSERT INTO INPUT_FILE VALUES
  ('tctest', 401, 'tc',       10,       98,'tc_test'); -- NOTE: Two empty lines
INSERT INTO INPUT_FILE VALUES
  ('f1',     402, 'tc',    50000,   689318,'tc_d1000_parsize50000_xsb_nocyc');
INSERT INTO INPUT_FILE VALUES
  ('f2',     403, 'tc',    50000,   689318,'tc_d1000_parsize50000_xsb_cyc');
INSERT INTO INPUT_FILE VALUES
  ('f3',     404,  'tc',  250000,  3446506,'tc_d1000_parsize250000_xsb_nocyc');
INSERT INTO INPUT_FILE VALUES
  ('f4',     405,  'tc',  250000,  3446506,'tc_d1000_parsize250000_xsb_cyc');
INSERT INTO INPUT_FILE VALUES
  ('f5',     406,  'tc',  500000,  6893031,'tc_d1000_parsize500000_xsb_nocyc');
INSERT INTO INPUT_FILE VALUES
  ('f6',     407,  'tc',  500000,  6893031,'tc_d1000_parsize500000_xsb_cyc');
INSERT INTO INPUT_FILE VALUES
  ('f7',     408,  'tc',  500000,  7446477,'tc_d2000_parsize500000_xsb_nocyc');
INSERT INTO INPUT_FILE VALUES
  ('f8',     409,  'tc',  500000,  7446477,'tc_d2000_parsize500000_xsb_cyc');
INSERT INTO INPUT_FILE VALUES
  ('f9',     410,  'tc', 1000000, 14892982,'tc_d2000_parsize1000000_xsb_nocyc');
INSERT INTO INPUT_FILE VALUES
  ('f10',    411,  'tc', 1000000, 14892982,'tc_d2000_parsize1000000_xsb_cyc');

INSERT INTO INPUT_FILE VALUES
  ('wintest',420,  'tc',       3,       33,'win_test');

INSERT INTO INPUT_FILE VALUES
  ('j1test', 501, 'j1',      20,      238,'d1000_test');
INSERT INTO INPUT_FILE VALUES
  ('10k',    502, 'j1',   50000,   639300,'d1000_relsize10000_xsb_cyc');
INSERT INTO INPUT_FILE VALUES
  ('50k',    503, 'j1',  250000,  3196504,'d1000_relsize50000_xsb_cyc');
INSERT INTO INPUT_FILE VALUES
  ('250k',   504, 'j1', 1250000, 15982480,'d1000_relsize250000_xsb_cyc');
-- These are (probably) synonyms. TODO: Should be removed:
INSERT INTO INPUT_FILE VALUES
  ('1k10k',  505, 'j1',   50000,   639300,'d1000_relsize10000_xsb_cyc');
INSERT INTO INPUT_FILE VALUES
  ('1k50k',  506, 'j1',  250000,  3196504,'d1000_relsize50000_xsb_cyc');
INSERT INTO INPUT_FILE VALUES
  ('1k250k', 507, 'j1', 1250000, 15982480,'d1000_relsize250000_xsb_cyc');

INSERT INTO INPUT_FILE VALUES
  ('std',    601,  'dblp', 2437867, 128444409,'dblp');
INSERT INTO INPUT_FILE VALUES
  ('big',    602,  'dblp',50221773,3082908204,'dblp_big');

INSERT INTO INPUT_FILE VALUES
  ('wdat',   701,  'wine',     654,     26386, 'wine_data');

INSERT INTO INPUT_FILE VALUES
  ('r1test', 801,  'r1',        10,         0, '_virtual_gen_cur1_0');
INSERT INTO INPUT_FILE VALUES
  ('r1M',    802,  'r1',   1000000,         0, '_virtual_gen_cur1_1');
INSERT INTO INPUT_FILE VALUES
  ('r1M2',   803,  'r1',   1000000,         0, '_virtual_gen_cur1_2');
INSERT INTO INPUT_FILE VALUES
  ('r1H',    804,  'r1', 100000000,         0, '_virtual_gen_cur1_3');
INSERT INTO INPUT_FILE VALUES
  ('r1G',    805,  'r1',1000000000,         0, '_virtual_gen_cur1_4');

INSERT INTO INPUT_FILE VALUES
  ('r2test', 811,  'r2',        10,         0, '_virtual_gen_cur2_0');
INSERT INTO INPUT_FILE VALUES
  ('r2M',    812,  'r2',   1000000,         0, '_virtual_gen_cur2_1');
INSERT INTO INPUT_FILE VALUES
  ('r2M2',   813,  'r2',   1000000,         0, '_virtual_gen_cur2_2');
INSERT INTO INPUT_FILE VALUES
  ('r2H',    814,  'r2', 100000000,         0, '_virtual_gen_cur2_3');
INSERT INTO INPUT_FILE VALUES
  ('r2G',    815,  'r2',1000000000,         0, '_virtual_gen_cur2_4');

-- ============================================================================
-- Automatically Added Files:
-- ============================================================================

-- DO NOT DELETE THIS MARK

