-- ============================================================================
-- Project:	rbench - Logic Programming and Database Benchmarks
-- Filename:	db/input_graphs.sql
-- Purpose:	Database for Benchmark Runs: Data of Input Graphs
-- Last Change:	11.10.2018
-- Language:	SQL (Tested with PostgreSQL)
-- Author:	Stefan Brass
-- EMail:	brass@informatik.uni-halle.de
-- WWW:		http://www.informatik.uni-halle.de/~brass/
-- Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
-- Copyright:	(c) 2016-2018 by Stefan Brass
-- License:	See file "LICENSE" for copying conditions.
-- Note:	There is no warranty at all - this code may contain bugs.
-- ============================================================================


-- ============================================================================
-- More Data on Data Files That are Directed Graphs:
-- ============================================================================

-- CREATE TABLE INPUT_GRAPH (
--	FILE_ID        VARCHAR(10) NOT NULL,
--	GTYPE          CHAR(1)     NOT NULL,
--	PARAM_1        NUMERIC(12) NULL,
--	PARAM_2        NUMERIC(12) NULL,
--	NUM_NODES      NUMERIC(12) NOT NULL,
--	NUM_EDGES      NUMERIC(12) NOT NULL,
--	DUP_EDGES      NUMERIC(12) NOT NULL,
--	LOOPS          CHAR(1)     NOT NULL,
--	MIN_IN_DEGREE  NUMERIC(12) NOT NULL,
--	MAX_IN_DEGREE  NUMERIC(12) NOT NULL,
--	MIN_OUT_DEGREE NUMERIC(12) NOT NULL,
--	MAX_OUT_DEGREE NUMERIC(12) NOT NULL,
--	CYCLES         CHAR(1)     NOT NULL,
--	TC_SIZE        NUMERIC(12) NOT NULL,
--	NUM_ITER       NUMERIC(12) NOT NULL,
--	COST           NUMERIC(12) NOT NULL,
--	CONSTRAINT INPUT_GRAPH_PK
--		PRIMARY KEY(FILE_ID),
--	CONSTRAINT INPUT_GRAPH_REF_INPUT_FILE
--		FOREIGN KEY(FILE_ID) REFERENCES INPUT_FILE,
--	CONSTRAINT INPUT_GRAPH_REF_GRAPH_TYPE
--		FOREIGN KEY (GTYPE) REFERENCES GRAPH_TYPE,
--	CONSTRAINT INPUT_GRAPH_PARAM_1_NONNEGATIVE
--		CHECK(PARAM_1 >= 0),
--	CONSTRAINT INPUT_GRAPH_PARAM_2_NONNEGATIVE
--		CHECK(PARAM_2 >= 0),
--	CONSTRAINT INPUT_GRAPH_NUM_NODES_NONNEGATIVE
--		CHECK(NUM_NODES >= 0),
--	CONSTRAINT INPUT_GRAPH_NUM_EDGES_NONNEGATIVE
--		CHECK(NUM_EDGES >= 0),
--	CONSTRAINT INPUT_GRAPH_DUP_EDGES_NONNEGATIVE
--		CHECK(DUP_EDGES >= 0),
--	CONSTRAINT INPUT_GRAPH_LOOPS_YES_NO
--		CHECK(LOOPS  in ('Y','N')),
--	CONSTRAINT INPUT_GRAPH_MIN_IN_DEGREE_NONNEGATIVE
--		CHECK(MIN_IN_DEGREE >= 0),
--	CONSTRAINT INPUT_GRAPH_MAX_IN_DEGREE_NONNEGATIVE
--		CHECK(MAX_IN_DEGREE >= 0),
--	CONSTRAINT INPUT_GRAPH_MIN_OUT_DEGREE_NONNEGATIVE
--		CHECK(MIN_OUT_DEGREE >= 0),
--	CONSTRAINT INPUT_GRAPH_MAX_OUT_DEGREE_NONNEGATIVE
--		CHECK(MAX_OUT_DEGREE >= 0),
--	CONSTRAINT INPUT_GRAPH_CYCLES_YES_NO
--		CHECK(CYCLES IN ('Y','N')),
--	CONSTRAINT INPUT_GRAPH_TC_SIZE_NONNEGATIVE
--		CHECK(TC_SIZE >= 0),
--	CONSTRAINT INPUT_GRAPH_NUM_ITER_NONNEGATIVE
--		CHECK(NUM_ITER >= 0),
--	CONSTRAINT INPUT_GRAPH_COST_NONNEGATIVE
--		CHECK(COST >= 0));


-- PARAM_1 and PARAM_2 are the parameters for the Data Generation Program

-- DUP_EDGES is the number of duplicate edges,
-- i.e. the number of node pairs (x,y) such that there are at least two edges
-- between these nodes.
-- Normally, it should be 0.
-- However, the OpenRuleBench graph generation program generates such
-- duplicate edges for acyclic graphs.
-- Therefore, our graph analysis checks the input files for this case.

-- LOOPS='Y' means that there are edges of the form (x,x).

-- COST is the number of applicable rule instances in the standard
-- tail-recursive Prolog program for computing the transitive closure:
--	tc(X, Y) :- par(X, Y).
--	tc(X, Z) :- par(X, Y), tc(Y, Z).
-- COST is the number of rule instances that semi-naive evaluation would
-- consider.
-- It can be computed as the sum of the number of edges
-- (i.e. the size of the par relation) and
-- the size of the join of par and tc.


-- ============================================================================
-- INSERT Statements for Input Graph Data:
-- ============================================================================


INSERT INTO INPUT_GRAPH VALUES('b17','B',17,NULL,
131071,131070,0,'N',0,1,0,2,'N',1966082,16,1966082);

INSERT INTO INPUT_GRAPH VALUES('b18','B',18,NULL,
262143,262142,0,'N',0,1,0,2,'N',4194306,17,4194306);

INSERT INTO INPUT_GRAPH VALUES('b19','B',19,NULL,
524287,524286,0,'N',0,1,0,2,'N',8912898,18,8912898);

INSERT INTO INPUT_GRAPH VALUES('c1k','C',1000,NULL,
1000,1000,0,'N',1,1,1,1,'Y',1000000,1000,1001000);

INSERT INTO INPUT_GRAPH VALUES('c2k','C',2000,NULL,
2000,2000,0,'N',1,1,1,1,'Y',4000000,2000,4002000);

INSERT INTO INPUT_GRAPH VALUES('c3k','C',3000,NULL,
3000,3000,0,'N',1,1,1,1,'Y',9000000,3000,9003000);

INSERT INTO INPUT_GRAPH VALUES('c4k','C',4000,NULL,
4000,4000,0,'N',1,1,1,1,'Y',16000000,4000,16004000);

INSERT INTO INPUT_GRAPH VALUES('k500','K',500,NULL,
500,250000,0,'Y',500,500,500,500,'Y',250000,1,125250000);

INSERT INTO INPUT_GRAPH VALUES('k1k','K',1000,NULL,
1000,1000000,0,'Y',1000,1000,1000,1000,'Y',1000000,1,1001000000);

INSERT INTO INPUT_GRAPH VALUES('k2k','K',2000,NULL,
2000,4000000,0,'Y',2000,2000,2000,2000,'Y',4000000,1,8004000000);

INSERT INTO INPUT_GRAPH VALUES('t500','T',500,NULL,
500,124750,0,'N',0,499,0,499,'N',124750,1,62126000);

INSERT INTO INPUT_GRAPH VALUES('t1k','T',1000,NULL,
1000,499500,0,'N',0,999,0,999,'N',499500,1,166666500);

INSERT INTO INPUT_GRAPH VALUES('t2k','T',2000,NULL,
2000,1999000,0,'N',0,1999,0,1999,'N',1999000,1,1333333000);

INSERT INTO INPUT_GRAPH VALUES('m4ki_2','M', 4096, 2,
8192,8190,0,'N',0,1,0,1,'N',16773120,4095,16773120);

INSERT INTO INPUT_GRAPH VALUES('m1ki_8','M', 1024, 8,
8192,8184,0,'N',0,1,0,1,'N',4190208,1023,4190208);

INSERT INTO INPUT_GRAPH VALUES('m256_32','M', 256, 32,
8192,8160,0,'N',0,1,0,1,'N',1044480,255,1044480);

INSERT INTO INPUT_GRAPH VALUES('m64_128','M',64,128,
8192,8064,0,'N',0,1,0,1,'N',258048,63,258048);

INSERT INTO INPUT_GRAPH VALUES('m16_512','M', 16, 512,
8192,7680,0,'N',0,1,0,1,'N',61440,15,61440);

INSERT INTO INPUT_GRAPH VALUES('m4_2ki','M', 4, 2048,
8192,6144,0,'N',0,1,0,1,'N',12288,3,12288);

INSERT INTO INPUT_GRAPH VALUES('p1k','P',1000,NULL,
1000,999,0,'N',0,1,0,1,'N',499500,999,499500);

INSERT INTO INPUT_GRAPH VALUES('p2k','P',2000,NULL,
2000,1999,0,'N',0,1,0,1,'N',1999000,1999,1999000);

INSERT INTO INPUT_GRAPH VALUES('p3k','P',3000,NULL,
3000,2999,0,'N',0,1,0,1,'N',4498500,2999,4498500);

INSERT INTO INPUT_GRAPH VALUES('p4k','P',4000,NULL,
4000,3999,0,'N',0,1,0,1,'N',7998000,3999,7998000);

INSERT INTO INPUT_GRAPH VALUES('s2k_1','S', 2000, 1,
2000,4000,0,'N',2,2,2,2,'Y',4000000,1000,8004000);

INSERT INTO INPUT_GRAPH VALUES('s2k_2','S', 2000, 2,
2000,6000,0,'N',3,3,3,3,'Y',4000000,288,12006000);

INSERT INTO INPUT_GRAPH VALUES('s2k_3','S', 2000, 3,
2000,8000,0,'N',4,4,4,4,'Y',4000000,500,16008000);

INSERT INTO INPUT_GRAPH VALUES('s2k_4','S', 2000, 4,
2000,10000,0,'N',5,5,5,5,'Y',4000000,400,20010000);

INSERT INTO INPUT_GRAPH VALUES('s2k_5','S', 2000, 5,
2000,12000,0,'N',6,6,6,6,'Y',4000000,127,24012000);

INSERT INTO INPUT_GRAPH VALUES('s1k_1','S', 1000, 1,
1000,2000,0,'N',2,2,2,2,'Y',1000000,500,2002000);

INSERT INTO INPUT_GRAPH VALUES('s1k_2','S', 1000, 2,
1000,3000,0,'N',3,3,3,3,'Y',1000000,201,3003000);

INSERT INTO INPUT_GRAPH VALUES('s1k_3','S', 1000, 3,
1000,4000,0,'N',4,4,4,4,'Y',1000000,250,4004000);

INSERT INTO INPUT_GRAPH VALUES('s1k_4','S', 1000, 4,
1000,5000,0,'N',5,5,5,5,'Y',1000000,200,5005000);

INSERT INTO INPUT_GRAPH VALUES('s1k_5','S', 1000, 5,
1000,6000,0,'N',6,6,6,6,'Y',1000000,42,6006000);

INSERT INTO INPUT_GRAPH VALUES('u1k_50k','U', 1000, 50000,
1000,50000,0,'N',46,51,46,51,'Y',1000000,3,50050000);

INSERT INTO INPUT_GRAPH VALUES('u1k_125k','U', 1000, 125000,
1000,125000,0,'N',122,127,122,127,'Y',1000000,2,125125000);

INSERT INTO INPUT_GRAPH VALUES('u1k_250k','U', 1000, 250000,
1000,250000,0,'N',248,251,248,251,'Y',1000000,2,250250000);

INSERT INTO INPUT_GRAPH VALUES('u2k_200k','U', 2000, 200000,
2000,200000,0,'N',98,101,98,101,'Y',4000000,3,400200000);

INSERT INTO INPUT_GRAPH VALUES('u2k_500k','U', 2000, 500000,
2000,500000,0,'N',248,251,248,251,'Y',4000000,2,1000500000);

INSERT INTO INPUT_GRAPH VALUES('u2k_1m','U', 2000, 1000000,
2000,1000000,0,'N',499,502,499,502,'Y',4000000,2,2001000000);

INSERT INTO INPUT_GRAPH VALUES('a1k_50k','A', 1000, 50000,
1000,50000,0,'N',0,102,0,102,'N',471621,8,15269270);

INSERT INTO INPUT_GRAPH VALUES('a1k_125k','A', 1000, 125000,
1000,125000,0,'N',0,250,0,250,'N',492680,5,40853746);

INSERT INTO INPUT_GRAPH VALUES('a1k_250k','A', 1000, 250000,
1000,250000,0,'N',0,500,0,501,'N',497763,4,82941061);

INSERT INTO INPUT_GRAPH VALUES('a2k_200k','A', 2000, 200000,
2000,200000,0,'N',0,201,0,201,'N',1944729,8,128420988);

INSERT INTO INPUT_GRAPH VALUES('a2k_500k','A', 2000, 500000,
2000,500000,0,'N',0,500,0,500,'N',1985321,6,330666855);

INSERT INTO INPUT_GRAPH VALUES('a2k_1m','A', 2000, 1000000,
2000,1000000,0,'N',0,1000,0,1000,'N',1995698,4,666033613);

INSERT INTO INPUT_GRAPH VALUES('y1k_4k','Y', 1000, 4000,
5000,4999,0,'N',0,1000,0,1,'N',11998000,4000,11998000);

INSERT INTO INPUT_GRAPH VALUES('y1k_8k','Y', 1000, 8000,
9000,8999,0,'N',0,1000,0,1,'N',39996000,8000,39996000);

INSERT INTO INPUT_GRAPH VALUES('y500_4k','Y', 500, 4000,
4500,4499,0,'N',0,500,0,1,'N',9998000,4000,9998000);

INSERT INTO INPUT_GRAPH VALUES('y500_8k','Y', 500, 8000,
8500,8499,0,'N',0,500,0,1,'N',35996000,8000,35996000);


-- ============================================================================
-- Automatically Added Input Graph Data:
-- ============================================================================

-- DO NOT DELETE THIS MARK

