# tcff

To improve performance,
we used a temporary in-memory table for the `par` relation.
We added `PRAGMA temp\_store = MEMORY;`
in order to deactivate using temporary files.

```sql
-- tcff.sql.tbl
PRAGMA temp_store = MEMORY;
CREATE TEMP TABLE par (
  a INT NOT NULL,
  b INT NOT NULL,
  CONSTRAINT par_pk PRIMARY KEY (a, b)
) WITHOUT ROWID;
CREATE INDEX par_fb ON par (b);
```
```sql
-- tcff.sql
WITH RECURSIVE tc(a,b) AS (
    SELECT par.a, par.b from par
    UNION
    SELECT par.a, tc.b from par JOIN tc ON par.b = tc.a
) SELECT Count(*) FROM tc;
```

Launch: `cat tcff.sql | sqlite3 -cmd ".read tcff.sql.tbl" -cmd ".read {instance}" -bail`
